@@ -1,4 +1,7 @@
 import datetime
+from typing import List
+
+from moco_wrapper.util.endpoint import Endpoint
 
 
 class MWRAPBase(object):
@@ -22,3 +25,13 @@ class MWRAPBase(object):
             date_to_convert.month,
             date_to_convert.day
         ).isoformat()
+
+    @staticmethod
+    def endpoints() -> List[Endpoint]:
+        """
+        Returns all models associated with the model
+
+        :returns: List of endpoint objects
+        :rtype: list
+        """
+        return []
