@@ -54,7 +54,8 @@ class Project(MWRAPBase):
             Endpoint("project_get", "/projects/{id}", "GET", om.Project),
             Endpoint("project_getlist", "/projects", "GET", om.Project),
             Endpoint("project_assigned", "/projects/assigned", "GET", om.Project),
-            Endpoint("project_report", "/projects/{id}/report", "GET", om.ProjectReport)
+            Endpoint("project_report", "/projects/{id}/report", "GET", om.ProjectReport),
+            Endpoint("project_destroy", "/projects/{id}", "DELETE")
         ]
 
     def __init__(self, moco):
@@ -82,7 +83,7 @@ class Project(MWRAPBase):
         billing_variant: ProjectBillingVariant = None,
         hourly_rate: float = None,
         budget: float = None,
-        labels: list = None,
+        tags: list = None,
         custom_properties: dict = None,
         info: str = None,
         fixed_price: bool = False,
@@ -105,7 +106,7 @@ class Project(MWRAPBase):
         :param billing_variant: Billing variant used (default ``None``)
         :param hourly_rate: Hourly rate that will get billed (default ``None``)
         :param budget: Budget for the project (default ``None``)
-        :param labels: Array of additional labels (default ``None``)
+        :param tags: Array of additional tags (default ``None``)
         :param custom_properties: Custom values used by the project (default ``None``)
         :param info: Additional information (default ``None``)
         :param fixed_price: If the project is a fixed price projects (default ``False``)
@@ -125,7 +126,7 @@ class Project(MWRAPBase):
         :type billing_variant: :class:`.ProjectBillingVariant`, str
         :type hourly_rate: float
         :type budget: float
-        :type labels: list
+        :type tags: list
         :type custom_properties: dict
         :type info: str
         :type fixed_price: bool
@@ -161,7 +162,7 @@ class Project(MWRAPBase):
             ("billing_variant", billing_variant),
             ("hourly_rate", hourly_rate),
             ("budget", budget),
-            ("labels", labels),
+            ("tags", tags),
             ("custom_properties", custom_properties),
             ("info", info),
             ("fixed_price", fixed_price)
@@ -191,7 +192,7 @@ class Project(MWRAPBase):
         billing_variant: ProjectBillingVariant = None,
         hourly_rate: float = None,
         budget: float = None,
-        labels: list = None,
+        tags: list = None,
         custom_properties: dict = None,
         info: str = None
     ):
@@ -213,7 +214,7 @@ class Project(MWRAPBase):
         :param billing_variant: Billing variant used (default ``None``)
         :param hourly_rate: Hourly rate that will get billed (default ``None``)
         :param budget: Budget for the project (default ``None``)
-        :param labels: Array of additional labels (default ``None``)
+        :param tags: Array of additional tags (default ``None``)
         :param custom_properties: Custom values used by the project (default ``None``)
         :param info: Additional information (default ``None``)
 
@@ -232,7 +233,7 @@ class Project(MWRAPBase):
         :type billing_variant: :class:`.ProjectBillingVariant`, str
         :type hourly_rate: float
         :type budget: float
-        :type labels: list
+        :type tags: list
         :type custom_properties: dict
         :type info: str
 
@@ -259,7 +260,7 @@ class Project(MWRAPBase):
             ("billing_variant", billing_variant),
             ("hourly_rate", hourly_rate),
             ("budget", budget),
-            ("labels", labels),
+            ("tags", tags),
             ("custom_properties", custom_properties),
             ("info", info)
         ):
@@ -462,3 +463,28 @@ class Project(MWRAPBase):
         }
 
         return self._moco.get("project_report", ep_params=ep_params)
+
+    def destroy(
+        self,
+        project_id: int
+    ):
+        """
+        Deletes a project. Only possible if there are no activities, invoices, offers or expenses
+
+        :param project_id: Id of the project to delete
+
+        :type project_id: int
+
+        :returns: Empty response on success
+        :rtype: :class:`moco_wrapper.util.response.EmptyResponse`
+
+        .. note::
+            Deleting a project is only possible if there are no acitivities, invoices offers or
+            expenses
+        """
+
+        ep_params = {
+            "id": project_id
+        }
+
+        return self._moco.get("project_destroy", ep_params=ep_params)
