@@ -2,6 +2,7 @@ import datetime
 from typing import List
 
 from moco_wrapper.util.endpoint import Endpoint
+from moco_wrapper.util.io import File
 from moco_wrapper.models import objector_models as om
 from moco_wrapper.models.base import MWRAPBase
 
@@ -59,7 +60,10 @@ class ProjectExpense(MWRAPBase):
         description: str = None,
         billable: bool = True,
         budget_relevant: bool = False,
-        custom_properties: dict = None
+        service_period_from: datetime.date = None,
+        service_period_to: datetime.date = None,
+        custom_properties: dict = None,
+        file: File = None
     ):
         """
         Create a project expense.
@@ -74,7 +78,10 @@ class ProjectExpense(MWRAPBase):
         :param description: Description of the expense (default ``None``)
         :param billable: If this expense billable (default ``True``)
         :param budget_relevant: If this expense is budget relevant (default ``False``)
+        :param service_period_from: Service period start date (default ``None``)
+        :param service_period_to: Service period end date (default ``None``)
         :param custom_properties: Additional fields as dictionary (default ``None``)
+        :param file: File attached to the expense (default ``None``)
 
         :type project_id: int
         :type expense_date: datetime.date, str
@@ -86,7 +93,10 @@ class ProjectExpense(MWRAPBase):
         :type description: str
         :type billable: bool
         :type budget_relevant: bool
+        :type service_period_from: datetime.date, str
+        :type service_period_to: datetime.date, str
         :type custom_properties: dict
+        :type file: :class:`moco_wrapper.util.io.File`
 
         :returns: The created expense object
         :rtype: :class:`moco_wrapper.util.response.ObjectResponse`
@@ -113,9 +123,20 @@ class ProjectExpense(MWRAPBase):
             ("billable", billable),
             ("budget_relevant", budget_relevant),
             ("custom_properties", custom_properties),
+            ("service_period_from", service_period_from),
+            ("service_period_to", service_period_to),
+            ("file", file)
         ):
             if value is not None:
-                data[key] = value
+                if key in ["service_period_from", "service_period_to"] and isinstance(value, datetime.date):
+                    data[key] = self._convert_date_to_iso(value)
+                elif isinstance(value, File):
+                    data[key] = {
+                        "filename": value.name,
+                        "base64": value.to_base64()
+                    }
+                else:
+                    data[key] = value
 
         return self._moco.post("project_expense_create", ep_params=ep_params, data=data)
 
@@ -163,6 +184,8 @@ class ProjectExpense(MWRAPBase):
         description: str = None,
         billable: bool = None,
         budget_relevant: bool = None,
+        service_period_from: datetime.date = None,
+        service_period_to: datetime.date = None,
         custom_properties: dict = None
     ):
         """
@@ -179,6 +202,8 @@ class ProjectExpense(MWRAPBase):
         :param description: Description of the expense (default ``None``)
         :param billable: If this expense billable (default ``None``)
         :param budget_relevant: If this expense is budget relevant (default ``None``)
+        :param service_period_from: Service period start date (default ``None``)
+        :param service_period_to: Service period end date (default ``None``)
         :param custom_properties: Additional fields as dictionary (default ``None``)
 
         :type project_id: int
@@ -192,6 +217,8 @@ class ProjectExpense(MWRAPBase):
         :type description: str
         :type billable: bool
         :type budget_relevant: bool
+        :type service_period_from: datetime.date, str
+        :type service_period_to: datetime.date, str
         :type custom_properties: dict
 
         :returns: The updated expense object
@@ -213,10 +240,12 @@ class ProjectExpense(MWRAPBase):
             ("description", description),
             ("billable", billable),
             ("budget_relevant", budget_relevant),
+            ("service_period_from", service_period_from),
+            ("service_period_to", service_period_to),
             ("custom_properties", custom_properties)
         ):
             if value is not None:
-                if key in ["date"] and isinstance(value, datetime.date):
+                if key in ["date", "service_period_from", "service_period_to"] and isinstance(value, datetime.date):
                     data[key] = self._convert_date_to_iso(value)
                 else:
                     data[key] = value
