@@ -3,7 +3,8 @@ import time
 import collections
 
 from moco_wrapper.util.requestor.base import BaseRequestor
-from moco_wrapper.util.response import ListingResponse, JsonResponse, ErrorResponse, EmptyResponse, FileResponse
+from moco_wrapper.util.response import PagedListResponse, ListResponse, ObjectResponse, ErrorResponse, EmptyResponse, \
+    FileResponse
 
 
 class NoRetryRequestor(BaseRequestor):
@@ -94,12 +95,16 @@ class NoRetryRequestor(BaseRequestor):
 
                 # json response handling is the default
                 response_content = response.json()
-                # if response is a list, return listing response
+
+                # if response is a list, return list response
                 if isinstance(response_content, list):
-                    return ListingResponse(response)
+                    if "X-Page" in response.headers.keys():
+                        return PagedListResponse(response)  # response is a paged list
+                    else:
+                        return ListResponse(response) # response is an unpaged list
 
                 # return single json response
-                return JsonResponse(response)
+                return ObjectResponse(response)
 
             # check if the response has an error status code
             if response.status_code in self.ERROR_STATUS_CODES:
@@ -107,6 +112,6 @@ class NoRetryRequestor(BaseRequestor):
                 return error_response
 
         except ValueError as ex:
-            print("ValueError in response conversion:" + str(ex))
+            # print("ValueError in response conversion:" + str(ex))
             response_obj = ErrorResponse(response)
             return response_obj
