@@ -1,8 +1,10 @@
 from moco_wrapper.util.response import ObjectResponse, ListResponse, PagedListResponse, EmptyResponse
 from moco_wrapper.util.generator import ProjectExpenseGenerator
+from moco_wrapper.util.io import File
 from moco_wrapper.models.company import CompanyType
 
 from datetime import date
+from os import path
 from .. import IntegrationTest
 
 
@@ -69,6 +71,29 @@ class TestProjectExpense(IntegrationTest):
             assert ex_create.data.unit_price == unit_price
             assert ex_create.data.unit_cost == unit_cost
 
+    def test_create_with_file(self):
+        project = self.get_project()
+        pdf_path = path.join(path.dirname(path.dirname(__file__)), "files", "test_project_expense_create_with_file.pdf")
+        expense_file = File.load(pdf_path)
+
+        with self.recorder.use_cassette("TestProjectExpense.test_create_with_file"):
+            ex_create = self.moco.ProjectExpense.create(
+                project_id=project.id,
+                expense_date=date(2040, 1, 1),
+                title="test_project_expense_create_with_file",
+                quantity=1,
+                unit="stk",
+                unit_price=2,
+                unit_cost=4,
+                file=expense_file
+            )
+
+            assert ex_create.response.status_code == 200
+
+            assert type(ex_create) is ObjectResponse
+
+            assert ex_create.data.file_url is not None
+
     def test_create_full(self):
         project = self.get_project()
 
@@ -82,6 +107,8 @@ class TestProjectExpense(IntegrationTest):
             description = "misc tools"
             billable = True
             budget_relevant = True
+            service_period_from = date(2021, 1, 1)
+            service_period_to = date(2021, 1, 31)
 
             ex_create = self.moco.ProjectExpense.create(
                 project_id=project.id,
@@ -93,7 +120,9 @@ class TestProjectExpense(IntegrationTest):
                 unit_cost=unit_cost,
                 description=description,
                 billable=billable,
-                budget_relevant=budget_relevant
+                budget_relevant=budget_relevant,
+                service_period_from=service_period_from,
+                service_period_to=service_period_to
             )
 
             assert ex_create.response.status_code == 200
@@ -110,6 +139,8 @@ class TestProjectExpense(IntegrationTest):
             assert ex_create.data.description == description
             assert ex_create.data.billable == billable
             assert ex_create.data.budget_relevant == budget_relevant
+            assert ex_create.data.service_period_from == service_period_from.isoformat()
+            assert ex_create.data.service_period_to == service_period_to.isoformat()
 
     def test_get(self):
         project = self.get_project()
@@ -173,6 +204,8 @@ class TestProjectExpense(IntegrationTest):
             description = "misc tools"
             billable = True
             budget_relevant = True
+            service_period_from = date(2021, 1, 1)
+            service_period_to = date(2021, 3, 1)
 
             ex_create = self.moco.ProjectExpense.create(
                 project_id=project.id,
@@ -195,7 +228,9 @@ class TestProjectExpense(IntegrationTest):
                 unit_cost=unit_cost,
                 description=description,
                 billable=billable,
-                budget_relevant=budget_relevant
+                budget_relevant=budget_relevant,
+                service_period_from=service_period_from,
+                service_period_to=service_period_to
             )
 
             assert ex_create.response.status_code == 200
@@ -214,6 +249,8 @@ class TestProjectExpense(IntegrationTest):
             assert ex_update.data.description == description
             assert ex_update.data.billable == billable
             assert ex_update.data.budget_relevant == budget_relevant
+            assert ex_update.data.service_period_from == service_period_from.isoformat()
+            assert ex_update.data.service_period_to == service_period_to.isoformat()
 
     def test_delete(self):
         project = self.get_project()
@@ -351,4 +388,3 @@ class TestProjectExpense(IntegrationTest):
 
             assert type(ex_bulk) is ListResponse
             assert type(ex_disregard) is EmptyResponse
-
