@@ -10,7 +10,7 @@ from .. import IntegrationTest
 class TestSchedule(IntegrationTest):
     def get_user(self):
         with self.recorder.use_cassette("TestSchedule.get_user"):
-            user = self.moco.User.getlist().items[0]
+            user = self.moco.User.getlist()[0]
             return user
 
     def get_customer(self):
