@@ -5,7 +5,7 @@ from .. import IntegrationTest
 class TestUserHoliday(IntegrationTest):
     def get_user(self):
         with self.recorder.use_cassette("TestUserHoliday.get_user"):
-            user = self.moco.User.getlist().items[0]
+            user = self.moco.User.getlist()[0]
             return user
 
     def test_create(self):
