@@ -9,10 +9,18 @@ class TestPurchaseItemGenerator(object):
         tax = 7.7
         total = 20.3
         tax_included = False
+        category_id = 4
 
-        item = self.generator.generate_item(title, total, tax, tax_included=tax_included)
+        item = self.generator.generate_item(
+            title,
+            total,
+            tax,
+            tax_included=tax_included,
+            category_id=category_id
+        )
 
         assert item["title"] == title
         assert item["tax"] == tax
         assert item["total"] == total
         assert item["tax_included"] == tax_included
+        assert item["category_id"] == category_id
